==> xoops-2.5.7.1.txz: usr/local/www/xoops/htdocs/Frameworks/moduleclasses/moduleadmin/language/english/main.php <==
<?php
/**
 * Frameworks Module Admin
 *
 * You may not change or alter any portion of this comment or credits
 * of supporting developers from this source code or any supporting source code
 * which is considered copyrighted (c) material of the original comment or credit authors.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * @copyright   Grégory Mage (Aka Mage)
 * @license     GNU GPL 2 (http://www.gnu.org/licenses/old-licenses/gpl-2.0.html)
 * @author      Grégory Mage (Aka Mage)
 */
// Info
define('_AM_MODULEADMIN_CONFIG','Configuration Check');
define('_AM_MODULEADMIN_CONFIG_CHMOD',"The folder '%s' must be with a chmod '%s' (it's now set on %s).");
define('_AM_MODULEADMIN_CONFIG_FOLDERKO',"The folder '%s' does not exist");
define('_AM_MODULEADMIN_CONFIG_FOLDEROK',"The folder '%s' exists");
define('_AM_MODULEADMIN_CONFIG_PHP','Minimum PHP required: %s (your version is %s)');
define('_AM_MODULEADMIN_CONFIG_XOOPS','Minimum XOOPS required: %s (your version is %s)');
define('_AM_MODULEADMIN_CONFIG_DB','Minimum version required: %s (your version is %s)');
define('_AM_MODULEADMIN_CONFIG_ADMIN','Minimum ModuleAdmin required: %s (your version is %s)');
// About
define('_AM_MODULEADMIN_ABOUT_CHANGELOG','Change log');
define('_AM_MODULEADMIN_ABOUT_DESCRIPTION','Description');
define('_AM_MODULEADMIN_ABOUT_MODULEINFO','Module Info');
define('_AM_MODULEADMIN_ABOUT_MODULESTATUS','Status:');
define('_AM_MODULEADMIN_ABOUT_UPDATEDATE','Updated:');
define('_AM_MODULEADMIN_ABOUT_WEBSITE',"Website:");
define("_AM_MODULEADMIN_ABOUT_RELEASEDATE","Released: ");
define("_AM_MODULEADMIN_ABOUT_AUTHOR","Author: ");
define("_AM_MODULEADMIN_ABOUT_CREDITS","Credits: ");
define("_AM_MODULEADMIN_ABOUT_LICENSE","License: ");
define("_AM_MODULEADMIN_ABOUT_AUTHOR_NAME","Author name: ");
define("_AM_MODULEADMIN_ABOUT_AUTHOR_INFO","Author Info");
define("_AM_MODULEADMIN_HOME","Home");
define("_AM_MODULEADMIN_DASHBOARD","Dashboard");
define("_AM_MODULEADMIN_ABOUT","About");
define("_AM_MODULEADMIN_PERMISSIONS","Permissions");
//ModuleAdmin
define("_AM_MODULEADMIN_ADMIN_FOOTER","<div class='center smallsmall italic pad5'>This module is maintained by the <a class='tooltip' rel='external' href='http://xoops.org/' title='Visit XOOPS Community'>XOOPS Community</a></div>");

==> xoops-2.5.8.txz: usr/local/www/xoops/htdocs/Frameworks/moduleclasses/moduleadmin/language/english/main.php <==
<?php
/**
 * Frameworks Module Admin
 *
 * You may not change or alter any portion of this comment or credits
 * of supporting developers from this source code or any supporting source code
 * which is considered copyrighted (c) material of the original comment or credit authors.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * @copyright   Grégory Mage (Aka Mage)
 * @copyright   (c) 2000-2016 XOOPS Project (www.xoops.org)
 * @license     GNU GPL 2 (http://www.gnu.org/licenses/gpl-2.0.html)
 * @author      Grégory Mage (Aka Mage)
 */
// Info
define('_AM_MODULEADMIN_CONFIG','Configuration Check');
define('_AM_MODULEADMIN_CONFIG_CHMOD',"The folder '%s' must be with a chmod '%s' (it's now set on %s).");
define('_AM_MODULEADMIN_CONFIG_FOLDERKO',"The folder '%s' does not exist");
define('_AM_MODULEADMIN_CONFIG_FOLDEROK',"The folder '%s' exists");
define('_AM_MODULEADMIN_CONFIG_PHP','Minimum PHP required: %s (your version is %s)');
define('_AM_MODULEADMIN_CONFIG_XOOPS','Minimum XOOPS required: %s (your version is %s)');
define('_AM_MODULEADMIN_CONFIG_DB','Minimum version required: %s (your version is %s)');
define('_AM_MODULEADMIN_CONFIG_ADMIN','Minimum ModuleAdmin required: %s (your version is %s)');
// About
define('_AM_MODULEADMIN_ABOUT_CHANGELOG','Change log');
define('_AM_MODULEADMIN_ABOUT_DESCRIPTION','Description');
define('_AM_MODULEADMIN_ABOUT_MODULEINFO','Module Info');
define('_AM_MODULEADMIN_ABOUT_MODULESTATUS','Status:');
define('_AM_MODULEADMIN_ABOUT_UPDATEDATE','Updated:');
define('_AM_MODULEADMIN_ABOUT_WEBSITE', 'Website:');
define('_AM_MODULEADMIN_ABOUT_RELEASEDATE', 'Released: ');
define('_AM_MODULEADMIN_ABOUT_AUTHOR', 'Author: ');
define('_AM_MODULEADMIN_ABOUT_CREDITS', 'Credits: ');
define('_AM_MODULEADMIN_ABOUT_LICENSE', 'License: ');
define('_AM_MODULEADMIN_ABOUT_AUTHOR_NAME', 'Author name: ');
define('_AM_MODULEADMIN_ABOUT_AUTHOR_INFO', 'Author Info');
define('_AM_MODULEADMIN_HOME', 'Home');
define('_AM_MODULEADMIN_DASHBOARD', 'Dashboard');
define('_AM_MODULEADMIN_ABOUT', 'About');
define('_AM_MODULEADMIN_PERMISSIONS', 'Permissions');
//ModuleAdmin
define('_AM_MODULEADMIN_ADMIN_FOOTER',"<div class='center smallsmall italic pad5'>This module is maintained by the <a class='tooltip' rel='external' href='http://xoops.org/' title='Visit XOOPS Community'>XOOPS Community</a></div>");
